@@ -24,6 +24,7 @@ pub enum KeyPairError {
     InvalidEntropy,
     ScalarFormatError,
     EquationFalse,
+    SignatureError,
 }
 
 /// HMAC algorithm errors.
@@ -73,6 +74,18 @@ impl From<schnorrkel::SignatureError> for KeyPairError {
     }
 }
 
+impl From<ed25519_dalek::ed25519::Error> for KeyPairError {
+    fn from(_: ed25519_dalek::ed25519::Error) -> Self {
+        Self::SignatureError
+    }
+}
+
+impl From<ed25519_dalek::ed25519::Error> for SignatureError {
+    fn from(_: ed25519_dalek::ed25519::Error) -> Self {
+        Self::EquationFalse
+    }
+}
+
 #[cfg(feature = "std")]
 impl Display for AeadError {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
